@@ -125,7 +125,7 @@ def put(environ, start_response):
 
     recipe = Recipe(recipe_name)
     store = environ['tiddlyweb.store']
-    length = environ['CONTENT_LENGTH']
+    length, _ = web.content_length_and_type(environ)
 
     usersign = environ['tiddlyweb.usersign']
 
