@@ -56,16 +56,16 @@ def load_app(app_prefix=None, dirname=None):
 
 def start_cherrypy(config):
     """
-    Start a cherrypy webserver to run our app.
+    Start a CherryPy webserver to run our app.
     """
-    from cherrypy import wsgiserver
+    from cherrypy.wsgiserver import CherryPyWSGIServer
     hostname = config['server_host']['host']
     port = int(config['server_host']['port'])
     scheme = config['server_host']['scheme']
     app = load_app()
-    server = wsgiserver.CherryPyWSGIServer((hostname, port), app)
+    server = CherryPyWSGIServer((hostname, port), app)
     try:
-        logging.debug('starting cherrypy at %s://%s:%s',
+        logging.debug('starting CherryPy at %s://%s:%s',
                 scheme, hostname, port)
         std_error_message("Starting CherryPy at %s://%s:%s"
                 % (scheme, hostname, port))
